fluteline - easy pipelines
==========================

Easy to use thread based pipelines of producers, consumers, and consumer-producers, in pure python (2 and 3) and with no dependencies.

Installation
------------

.. code-block:: bash

    pip install fluteline

Links
-----

* Documentation: https://fluteline.readthedocs.io/en/latest
* Source code: https://github.com/Nagasaki45/fluteline
* PyPI releases: https://pypi.org/project/fluteline
* License: `MIT <https://github.com/Nagasaki45/fluteline/blob/master/LICENSE>`_
* Test status: https://travis-ci.org/Nagasaki45/fluteline
